#!/usr/bin/wish

# Frodo Tk GUI by Lutz Vieweg <lkv@mania.robin.de>
# requires Tk >= 4.1

#package require Tk 4.1

set FrodoFileTypes {
    {"All Frodo Projects" .fpr }
    {"All Files" *}
}

proc LoadFrodoFile {} {
    global FrodoFileTypes
    set file [tk_getOpenFile -filetypes $FrodoFileTypes -parent .]
    puts -nonewline "l{$file}"
    flush stdout
}

proc SaveFrodoFile {} {
    global FrodoFileTypes
    set file [tk_getSaveFile -filetypes $FrodoFileTypes -parent .]
    puts -nonewline "s{$file}"
    flush stdout
}

proc ShowAbout {} {
    tk_dialog .about "About" "Frodo V4.1b by Christian Bauer\nLinux port by Bernd Schmidt and Lutz Vieweg\nLykia customization by Stefan Mader" {} {} "OK"
}

proc ShowKeyboard {} {
    tk_dialog .keyboard "Keyboard Controls"	"Emulator:\n\n<Alt>+W = Warp Mode\n<Alt>+P = Pause Mode\n<Alt>+J = Switch Hardware Joystick\n<Alt>+S = Sound Off / On\n<Alt>+1..<Alt>+9 = Change Volume\n<F10>,<Alt>X,<Alt>Q = Quit\n\nIn Game:\n\n<Numpad>8,2,4,6 = Up,Down,Left,Right\n<Numpad>0 = Fire\n<Space> = Open Inventory\n<Delete> = Fix Jiggling in Animations\n<F1> = Help\n"  {} {} "OK"
}

proc Quit {} {
    set answer [tk_messageBox -type yesno -icon question -title Question -message "Are you sure to quit?"]
    switch -- $answer {
        yes {
            puts -nonewline "q"
            flush stdout
            exit 0
        }
    }
}

proc RestartEmulation {} {
	puts -nonewline "r"
	flush stdout
}

proc ListenToFrodo {} {
	set line [gets stdin]
	set cmd [lindex $line 0]
	switch -exact $cmd {
		"quit" {
			exit 0
		}
		"ping" {
			puts -nonewline "o"
			flush stdout
		}
		"maybequit" {
		    Quit
		}
	}
}

menu .menu
. configure -menu .menu

menu .menubar_options -tearoff 0
menu .menubar_help -tearoff 0
.menu add cascade -menu .menubar_options -label File -underline 0
.menubar_options add command -label Load -command LoadFrodoFile
.menubar_options add command -label Save -command SaveFrodoFile
.menubar_options add command -label "Reset Emulation" -command RestartEmulation
.menubar_options add command -label Quit -command Quit

.menu add cascade -menu .menubar_help -label Help -underline 0
.menubar_help add command -label Keyboard -command ShowKeyboard
.menubar_help add command -label About -command ShowAbout

option add *Dialog.msg.wrapLength 12i interactive

fileevent stdin readable { ListenToFrodo }

wm title . "Lykia - Options"
wm protocol . WM_DELETE_WINDOW Quit
wm minsize . 320 30
wm maxsize . 320 30
wm geometry . 320x0+0+0

tkwait window .

